<?php

namespace Litecms\Modeartorgroupquery\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Modeartorgroupquery\Http\Requests\ModeartorGroupQueryRequest;
use Litecms\Modeartorgroupquery\Interfaces\ModeartorGroupQueryRepositoryInterface;
use Litecms\Modeartorgroupquery\Models\ModeartorGroupQuery;

/**
 * Resource controller class for modeartor_group_query.
 */
class ModeartorGroupQueryResourceController extends BaseController
{

    /**
     * Initialize modeartor_group_query resource controller.
     *
     * @param type ModeartorGroupQueryRepositoryInterface $modeartor_group_query
     *
     * @return null
     */
    public function __construct(ModeartorGroupQueryRepositoryInterface $modeartor_group_query)
    {
        parent::__construct();
        $this->repository = $modeartor_group_query;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Modeartorgroupquery\Repositories\Criteria\ModeartorGroupQueryResourceCriteria::class);
    }

    /**
     * Display a list of modeartor_group_query.
     *
     * @return Response
     */
    public function index(ModeartorGroupQueryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Modeartorgroupquery\Repositories\Presenter\ModeartorGroupQueryPresenter::class)
                ->$function();
        }

        $modeartor_group_queries = $this->repository->paginate();

        return $this->response->title(trans('modeartorgroupquery::modeartor_group_query.names'))
            ->view('modeartorgroupquery::modeartor_group_query.index', true)
            ->data(compact('modeartor_group_queries'))
            ->output();
    }

    /**
     * Display modeartor_group_query.
     *
     * @param Request $request
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function show(ModeartorGroupQueryRequest $request, ModeartorGroupQuery $modeartor_group_query)
    {

        if ($modeartor_group_query->exists) {
            $view = 'modeartorgroupquery::modeartor_group_query.show';
        } else {
            $view = 'modeartorgroupquery::modeartor_group_query.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('modeartorgroupquery::modeartor_group_query.name'))
            ->data(compact('modeartor_group_query'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new modeartor_group_query.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ModeartorGroupQueryRequest $request)
    {

        $modeartor_group_query = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('modeartorgroupquery::modeartor_group_query.name')) 
            ->view('modeartorgroupquery::modeartor_group_query.create', true) 
            ->data(compact('modeartor_group_query'))
            ->output();
    }

    /**
     * Create new modeartor_group_query.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ModeartorGroupQueryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $modeartor_group_query                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('modeartorgroupquery::modeartor_group_query.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('modeartorgroupquery/modeartor_group_query/' . $modeartor_group_query->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/modeartorgroupquery/modeartor_group_query'))
                ->redirect();
        }

    }

    /**
     * Show modeartor_group_query for editing.
     *
     * @param Request $request
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function edit(ModeartorGroupQueryRequest $request, ModeartorGroupQuery $modeartor_group_query)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('modeartorgroupquery::modeartor_group_query.name'))
            ->view('modeartorgroupquery::modeartor_group_query.edit', true)
            ->data(compact('modeartor_group_query'))
            ->output();
    }

    /**
     * Update the modeartor_group_query.
     *
     * @param Request $request
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function update(ModeartorGroupQueryRequest $request, ModeartorGroupQuery $modeartor_group_query)
    {
        try {
            $attributes = $request->all();

            $modeartor_group_query->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('modeartorgroupquery::modeartor_group_query.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('modeartorgroupquery/modeartor_group_query/' . $modeartor_group_query->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('modeartorgroupquery/modeartor_group_query/' . $modeartor_group_query->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the modeartor_group_query.
     *
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function destroy(ModeartorGroupQueryRequest $request, ModeartorGroupQuery $modeartor_group_query)
    {
        try {

            $modeartor_group_query->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('modeartorgroupquery::modeartor_group_query.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('modeartorgroupquery/modeartor_group_query/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('modeartorgroupquery/modeartor_group_query/' . $modeartor_group_query->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple modeartor_group_query.
     *
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function delete(ModeartorGroupQueryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('modeartorgroupquery::modeartor_group_query.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('modeartorgroupquery/modeartor_group_query'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/modeartorgroupquery/modeartor_group_query'))
                ->redirect();
        }

    }

    /**
     * Restore deleted modeartor_group_queries.
     *
     * @param Model   $modeartor_group_query
     *
     * @return Response
     */
    public function restore(ModeartorGroupQueryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('modeartorgroupquery::modeartor_group_query.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/modeartorgroupquery/modeartor_group_query'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/modeartorgroupquery/modeartor_group_query/'))
                ->redirect();
        }

    }

}
